%define         major   7

Name:           libyui
Version:        3.2.7
Release:        %mkrel 1
Summary:        YaST2 User Interface Engine
Group:          System/Libraries
License:        LGPLv2+
URL:            https://github.com/libyui/libyui
Source0:        %{name}-%{version}.tar.bz2
Patch0:         libyui_external_widget_crash.patch
Patch1:         libyui_first_item_selection.patch

BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  texlive
BuildRequires:  texlive-texmf
BuildRequires:  ghostscript
BuildRequires:  boost-devel
BuildRequires:  libtool

%define    libname   %mklibname yui %{major}
%define    develname %mklibname -d yui

%description
libYUI is a library written entirely in C++ to provide an abstraction layer
for Qt, GTK and ncurses UI frameworks. This means that a single code in YUI
can be used to produce outputs using any of the 3 UI frameworks listed above.
This library was (and still is) used to create the YaST2 User Interface. 

#----------------------------------------------------------

%package -n %libname
Summary:      %{summary}
Group:        System/Libraries
Provides:     %{name} = %{version}-%{release}

Obsoletes:    %{name} < 2.21.1-2
Conflicts:    %{name} < 2.21.1-2

%description -n %libname
This package contains the library needed to run programs
dynamically linked with libyui.

%files -n %libname
%dir %{_libdir}/yui
%dir %{_datadir}/libyui
%{_libdir}/lib*.so.*
%doc COPYING* README.md

#----------------------------------------------------------

%package -n %develname
Summary:      libYUI, YaST2 User Interface Engine - header files
Group:        Development/C++
Requires:     %{name} >= %{version}
Requires:     boost-devel
Provides:     %{name}-devel = %{version}-%{release}
Provides:     yui-devel = %{version}-%{release}

Obsoletes:    %{name}-devel < 2.21.1-2
Conflicts:    %{name}-devel < 2.21.1-2

%description -n %develname
This is the development package for libyui user interface engine
that provides the abstraction from graphical user interfaces (Qt, Gtk)
and text based user interfaces (ncurses).

%files -n %develname
%dir %{_docdir}/libyui%{major}
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*
%{_includedir}/yui
%{_libdir}/cmake/libyui
%{_datadir}/libyui/buildtools
%doc %{_docdir}/libyui%{major}/examples
%doc %{_docdir}/libyui%{major}/html
%doc %{_docdir}/libyui%{major}/refman.pdf

#----------------------------------------------------------

%prep
%setup -q -n %{name}-%{version}
%autopatch -p1

%build
./bootstrap.sh
mkdir build
cd build
cmake \
    -DYPREFIX=%{_prefix} \
    -DDOC_DIR=%{_docdir}   \
    -DLIB_DIR=%{_lib}      \
    -DENABLE_DEBUG=1       \
    -DINSTALL_DOCS=yes     \
    -DCMAKE_BUILD_TYPE=RELWITHDEBINFO ..

make docs

%install
%make_install -C build
install -m0755 -d %{buildroot}/%{_libdir}/yui
find "%{buildroot}" -name "*.la" -delete


%changelog
* Sun Oct 09 2016 anaselli <anaselli> 3.2.7-1.mga6
+ Revision: 1059749
- new 2.3.7 as upstream
  Patch to avoid crash with externale widget plugins
  Patch to allow first item selection

* Fri Feb 12 2016 umeabot <umeabot> 3.2.3-0.git20151013.2.mga6
+ Revision: 956015
- Mageia 6 Mass Rebuild

* Tue Oct 13 2015 anaselli <anaselli> 3.2.3-0.git20151013.1.mga6
+ Revision: 890451
- new version 3.2.3 merged

* Wed Oct 15 2014 umeabot <umeabot> 3.1.4-0.git20140826.3.mga5
+ Revision: 741904
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.1.4-0.git20140826.2.mga5
+ Revision: 681910
- Mageia 5 Mass Rebuild

* Tue Aug 26 2014 anaselli <anaselli> 3.1.4-0.git20140826.1.mga5
+ Revision: 668479
- Fixed YLog building issue
- fixed source package
- updated to upstream master

* Fri Apr 18 2014 anaselli <anaselli> 3.1.3-0.git20140418.1.mga5
+ Revision: 616868
- Updated to 3.1.3 from anaselli branch

* Mon Apr 07 2014 anaselli <anaselli> 3.0.14-0.git20140407.1.mga5
+ Revision: 612761
- Fixed a crash if loading yui-mga first

* Sun Mar 30 2014 anaselli <anaselli> 3.0.13-0.git20140316.2.mga5
+ Revision: 610485
- Added debug symbols

* Sat Mar 29 2014 anaselli <anaselli> 3.0.13-0.git20140316.1.mga5
+ Revision: 609604
- new version 3.0.13

* Wed Nov 27 2013 anaselli <anaselli> 3.0.10-0.git20131124.1.mga4
+ Revision: 553785
- missed texlive-texmf dependency
- updated to upstream/master and anaselli branch for mageia plugin management

  + umeabot <umeabot>
    - Mageia 4 Mass Rebuild

* Tue Jul 09 2013 fwang <fwang> 3.0.8-3.mga4
+ Revision: 451669
- rebuild for new boost

* Sun Jun 30 2013 anaselli <anaselli> 3.0.8-2.mga4
+ Revision: 448645
- License changed

* Sun Jun 30 2013 anaselli <anaselli> 3.0.8-1.mga4
+ Revision: 448633
- new version 3.0.8

* Thu Apr 11 2013 barjac <barjac> 2.42.4-0.git20130107.4.mga3
+ Revision: 409651
- rebuild for boost-1.53
- patched for boost-1.53 from upstream

* Sun Jan 20 2013 anaselli <anaselli> 2.42.4-0.git20130107.3.mga3
+ Revision: 389850
- Updated to master

* Sat Jan 12 2013 umeabot <umeabot> 2.42.4-0.git20130107.2.mga3
+ Revision: 358732
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 07 2013 anaselli <anaselli> 2.42.4-0.git20130107.1.mga3
+ Revision: 341368
- New upstream version 2.42.4

* Sat Nov 10 2012 anaselli <anaselli> 2.42.3-0.git20121105.1.mga3
+ Revision: 316866
- new version 2.42.3 (aligned to yui master)

* Sat Nov 03 2012 anaselli <anaselli> 2.42.2-0.git20121102.1.mga3
+ Revision: 313332
- Updated from fork https://github.com/anaselli/libyui to add missed functionality

* Mon Oct 29 2012 anaselli <anaselli> 2.42.2-0.git20120908.2.mga3
+ Revision: 311523
- Fixed boost-devel dependency for devel package

* Sun Sep 16 2012 anaselli <anaselli> 2.42.2-0.git20120908.1.mga3
+ Revision: 294602
- ed git date to allow upgradability
- Added documentation
- updated to 2.42.2-0840dd8

* Sun Jul 22 2012 anaselli <anaselli> 2.42.0-0.git.e327da9.1.mga3
+ Revision: 273570
- New libyui from git 2.42.0

  + matteo <matteo>
    - replaced %%_prefix/include with %%_includedir macro

* Sun Jun 17 2012 matteo <matteo> 2.21.1-2.mga3
+ Revision: 261175
- added missing major
- obsoletes previous release
- reviewed spec file (package names corrected)

* Sun Jun 17 2012 matteo <matteo> 2.21.1-1.mga3
+ Revision: 261156
- spec file reviewed (cleaned some rpmlint warnings)
- imported package libyui

